![screenshot](https://github.com/user-attachments/assets/87aaad04-f454-42aa-b9ac-e14d41f189ac)

## Unfold Django Admin Theme

[![PyPI - Version](https://img.shields.io/pypi/v/django-unfold.svg?style=for-the-badge)](https://pypi.org/project/django-unfold/)
[![Build](https://img.shields.io/github/actions/workflow/status/unfoldadmin/django-unfold/release.yml?style=for-the-badge)](https://github.com/unfoldadmin/django-unfold/actions?query=workflow%3Arelease)
![Pre Commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=for-the-badge)
![Code Style - Ruff](https://img.shields.io/badge/code%20style-ruff-30173D.svg?style=for-the-badge)

Unfold is a theme for Django admin that incorporates common best practices for building full-fledged admin areas. It is designed to work on top of the default administration provided by Django.

- **Documentation:** Full docs are available at [unfoldadmin.com](https://unfoldadmin.com?utm_medium=github&utm_source=unfold).
- **Unfold:** Demo site is available at [unfoldadmin.com](https://unfoldadmin.com?utm_medium=github&utm_source=unfold).
- **Formula:** Repository with demo implementation at [github.com/unfoldadmin/formula](https://github.com/unfoldadmin/formula?utm_medium=github&utm_source=unfold).
- **Turbo:** Django & Next.js boilerplate implementing Unfold at [github.com/unfoldadmin/turbo](https://github.com/unfoldadmin/turbo?utm_medium=github&utm_source=unfold).
- **Discord:** Join the Unfold community on [Discord](https://discord.gg/9sQj9MEbNz).



## Are you using Unfold and need help?

Have you decided to start using Unfold but don’t have time to make the switch from the native Django admin? [Get in touch with us](https://unfoldadmin.com/consulting?utm_medium=github&utm_source=unfold) and let’s supercharge your development with our expertise.

## Features

- **Visual**: Provides a new user interface based on the Tailwind CSS framework.
- **Sidebar:** Simplifies the creation of sidebar navigation with icons, collapsibles, and more.
- **Dark mode:** Supports both light and dark mode versions.
- **Actions:** Offers multiple ways to define actions within different parts of the admin interface.
- **Filters:** Custom dropdowns, autocomplete, numeric, datetime, and text fields.
- **Dashboard:** Includes helpers for creating custom dashboard pages.
- **Components:** Reusable UI components such as cards, buttons, and charts.
- **WYSIWYG widget:** Built-in support for WYSIWYG (Trix).
- **Array widget:** Built-in widget for `django.contrib.postgres.fields.ArrayField`.
- **Inline tabs:** Groups inlines into tab navigation in the change form.
- **Model tabs:** Allows defining custom tab navigation for models.
- **Fieldset tabs:** Merges multiple fieldsets into tabs in the change form.
- **Sortable inlines:** Allows sorting inlines by dragging and dropping.
- **Environment label**: Distinguishes between environments by displaying a label.
- **Nonrelated inlines**: Displays nonrelated models as inlines in the change form.
- **Favicons**: Built-in support for configuring various site favicons.
- **Themes:** Allows customization of color scheme, background color, border radius, and more.
- **Font colors:** Adjusts font colors for better readability.
- **Changeform modes:** Displays fields in compressed mode in the change form.
- **Language switcher:** Change language directly from the admin area.
- **Parallel admin**: Supports [running the default admin](https://unfoldadmin.com/blog/migrating-django-admin-unfold/?utm_medium=github&utm_source=unfold) alongside Unfold.
- **Third party packages:** Default support for multiple popular applications.
- **Configuration:** Most basic options can be changed in `settings.py`.
- **Dependencies:** Fully based on `django.contrib.admin`.
- **VS Code**: Project configuration and development container included.
